.. _index:

===================
Kotti Documentation
===================

Kotti is a high-level, Pythonic web application framework based on Pyramid and SQLAlchemy.
It includes an extensible Content Management System called the Kotti CMS.

If you are a user of a Kotti system, and either found this page through browsing or searching, or were referred here, you will likely want to go directly to the `Kotti User Manual`_.

The documentation below is for developers of Kotti or applications built on top of it.

First Steps
-----------

Get an :ref:`overview <overview>` of what you can do with Kotti, how to :ref:`install <installation>` it and how to :ref:`create <tutorial>` your first Kotti project / add on.

.. toctree::
    :maxdepth: 2
    :titlesonly:

    first_steps/overview
    first_steps/installation
    first_steps/tutorial

Narrative Documentation
-----------------------

The narrative documentation contains various topics that explain how to use Kotti.

.. toctree::
    :maxdepth: 2
    :titlesonly:

    developing/basic/index
    developing/advanced/index

API
---

.. toctree::
    :maxdepth: 5
    :titlesonly:

    API documentation <api/index>

Getting Help / Contributing
---------------------------

.. toctree::
    :maxdepth: 1
    :titlesonly:

    help
    contributing

Future and Past
---------------

.. toctree::
    :maxdepth: 1
    :titlesonly:

    Roadmap <https://github.com/Kotti/Kotti/milestones>
    Changelog <changes>

.. _Kotti User Manual: https://kotti-user-manual.readthedocs.io/
.. _Roadmap: https://github.com/Kotti/Kotti/milestones
